# -*- coding: utf-8 -*- 
# @Time    : 04/15/2024 
# @Author  : nzooherd 
# @File    : video_bought.py 
# @Software: Visual Studio Code

from typing import Dict
from template import ATag, BTag, BaseTemplate, ITag, PTag, StrongTag

class VideoBoughtTemplate(BaseTemplate):

    def __init__(self, title, tags, preview_url, online_url, magnet_url, star) -> None:
        self.title = StrongTag().add(ATag(href=preview_url).value(title))
        self.star = PTag("⭐&nbsp&nbsp").add(BTag("评价星级&nbsp")).\
            add(StrongTag(self._star_value(star)))
        self.video_tags = PTag("🔖&nbsp&nbsp").add(BTag("个性标签&nbsp")).\
            add(StrongTag(self._tags_value(tags)))
        self.online_url = PTag("📹&nbsp&nbsp").add(BTag("在线观看&nbsp")).\
            add(StrongTag().add(ITag(self._online_url(online_url))))
        self.magnet_url = PTag("🧩&nbsp&nbsp").add(BTag("下载保存&nbsp")).\
            add(StrongTag().add(ITag(self._magnet_url(magnet_url))))
    
    def _star_value(self, star: int):
        assert 0 <= star <= 5, "star value error"
        value = ""
        for _ in range(star):
            value += "&nbsp&nbsp❤️"
        for _ in range(5 - star):
            value += "&nbsp&nbsp🤍"
        return value
    
    def _tags_value(self, tags: list[str]):
        return " " + " ".join("#" + tag for tag in set(tags))
    
    def _online_url(self, online_url: str):
        return f" <a href={online_url}>跳转到浏览器播放</a>"
    
    def _magnet_url(self, magnet_url: str):
        return f" <a href={magnet_url}>跳转到浏览器播放</a>"

    def hash_value(self) -> str:
        return f"{self.title}\n\n{self.star}\n\n{self.video_tags}\n\n{self.online_url}\n\n{self.magnet_url}"

    def template(self) -> Dict[str, str]:
        return {"html": self.hash_value()}
